AndroidWebViewController class

Implementation of the PlatformWebViewController with the Android WebView API.

Inheritance
  • Object
  • PlatformInterface
  • AndroidWebViewController

Constructors

AndroidWebViewController(PlatformWebViewControllerCreationParams params)
Creates a new AndroidWebViewController.

Properties

hashCode int
The hash code for this object.
no setterinherited
params → PlatformWebViewControllerCreationParams
The parameters used to initialize the PlatformWebViewController.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webViewIdentifier int
Identifier used to retrieve the underlying native WebView.
no setter

Methods

addJavaScriptChannel(JavaScriptChannelParams javaScriptChannelParams) Future<void>
Adds a new JavaScript channel to the set of enabled channels.
canGoBack() Future<bool>
Checks whether there's a back history item.
canGoForward() Future<bool>
Checks whether there's a forward history item.
clearCache() Future<void>
Clears all caches used by the WebView.
clearLocalStorage() Future<void>
Clears the local storage used by the WebView.
currentUrl() Future<String?>
Accessor to the current URL that the WebView is displaying.
enableZoom(bool enabled) Future<void>
Whether to support zooming using its on-screen zoom controls and gestures.
getScrollPosition() Future<Offset>
Return the current scroll position of this view.
getTitle() Future<String?>
Returns the title of the currently loaded page.
getUserAgent() Future<String?>
Gets the value used for the HTTP User-Agent: request header.
goBack() Future<void>
Goes back in the history of this WebView.
goForward() Future<void>
Goes forward in the history of this WebView.
isWebViewFeatureSupported(WebViewFeatureType featureType) Future<bool>
Checks if a WebView feature is supported on the current device.
loadFile(String absoluteFilePath) Future<void>
Loads the file located on the specified absoluteFilePath.
loadFileWithParams(LoadFileParams params) Future<void>
Loads a local HTML file using the provided params.
loadFlutterAsset(String key) Future<void>
Loads the Flutter asset specified in the pubspec.yaml file.
loadHtmlString(String html, {String? baseUrl}) Future<void>
Loads the supplied HTML string.
loadRequest(LoadRequestParams params) Future<void>
Makes a specific HTTP request ands loads the response in the webview.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() Future<void>
Reloads the current URL.
removeJavaScriptChannel(String javaScriptChannelName) Future<void>
Removes the JavaScript channel with the matching name from the set of enabled channels.
runJavaScript(String javaScript) Future<void>
Runs the given JavaScript in the context of the current page.
runJavaScriptReturningResult(String javaScript) Future<Object>
Runs the given JavaScript in the context of the current page, and returns the result.
scrollBy(int x, int y) Future<void>
Move the scrolled position of this view.
scrollTo(int x, int y) Future<void>
Set the scrolled position of this view.
setAllowContentAccess(bool enabled) Future<void>
Enables or disables content URL access.
setAllowFileAccess(bool allow) Future<void>
Sets the file access permission for the web view.
setBackgroundColor(Color color) Future<void>
Set the current background color of this view.
setCustomWidgetCallbacks({required OnShowCustomWidgetCallback? onShowCustomWidget, required OnHideCustomWidgetCallback? onHideCustomWidget}) Future<void>
Sets the callbacks that are invoked when the host application wants to show or hide a custom widget.
setGeolocationEnabled(bool enabled) Future<void>
Sets whether Geolocation is enabled.
setGeolocationPermissionsPromptCallbacks({OnGeolocationPermissionsShowPrompt? onShowPrompt, OnGeolocationPermissionsHidePrompt? onHidePrompt}) Future<void>
Sets the callback that is invoked when the client request handle geolocation permissions.
setHorizontalScrollBarEnabled(bool enabled) Future<void>
Whether the horizontal scrollbar should be drawn or not.
setJavaScriptMode(JavaScriptMode javaScriptMode) Future<void>
Sets the JavaScript execution mode to be used by the webview.
setMediaPlaybackRequiresUserGesture(bool require) Future<void>
Sets the restrictions that apply on automatic media playback.
setMixedContentMode(MixedContentMode mode) Future<void>
Configures the WebView's behavior when handling mixed content.
setOnConsoleMessage(void onConsoleMessage(JavaScriptConsoleMessage consoleMessage)) Future<void>
Sets a callback that notifies the host application of any log messages written to the JavaScript console.
setOnJavaScriptAlertDialog(Future<void> onJavaScriptAlertDialog(JavaScriptAlertDialogRequest request)) Future<void>
Sets a callback that notifies the host application that the web page wants to display a JavaScript alert() dialog.
setOnJavaScriptConfirmDialog(Future<bool> onJavaScriptConfirmDialog(JavaScriptConfirmDialogRequest request)) Future<void>
Sets a callback that notifies the host application that the web page wants to display a JavaScript confirm() dialog.
setOnJavaScriptTextInputDialog(Future<String> onJavaScriptTextInputDialog(JavaScriptTextInputDialogRequest request)) Future<void>
Sets a callback that notifies the host application that the web page wants to display a JavaScript prompt() dialog.
setOnPlatformPermissionRequest(void onPermissionRequest(PlatformWebViewPermissionRequest request)) Future<void>
Sets a callback that notifies the host application that web content is requesting permission to access the specified resources.
setOnScrollPositionChange(void onScrollPositionChange(ScrollPositionChange scrollPositionChange)?) Future<void>
Sets the listener for content offset changes.
setOnShowFileSelector(Future<List<String>> onShowFileSelector(FileSelectorParams params)?) Future<void>
Sets the callback that is invoked when the client should show a file selector.
setOverScrollMode(WebViewOverScrollMode mode) Future<void>
Sets the over-scroll mode for the WebView.
setPaymentRequestEnabled(bool enabled) Future<void>
Sets whether the WebView should enable the Payment Request API.
setPlatformNavigationDelegate(covariant AndroidNavigationDelegate handler) Future<void>
Sets the PlatformNavigationDelegate containing the callback methods that are called during navigation events.
setTextZoom(int textZoom) Future<void>
Sets the text zoom of the page in percent.
setUserAgent(String? userAgent) Future<void>
Sets the value used for the HTTP User-Agent: request header.
setUseWideViewPort(bool use) Future<void>
Sets whether the WebView should enable support for the "viewport" HTML meta tag or should use a wide viewport.
setVerticalScrollBarEnabled(bool enabled) Future<void>
Whether the vertical scrollbar should be drawn or not.
supportsSetScrollBarsEnabled() bool
Returns true if the current platform supports setting whether scrollbars should be drawn or not.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

enableDebugging(bool enabled) Future<void>
Whether to enable the platform's webview content debugging tools.