setAllowFileAccess method
Sets the file access permission for the web view.
The default value is true for apps targeting API 29 and below, and false when targeting API 30 and above.
Implementation
Future<void> setAllowFileAccess(bool allow) =>
_webView.settings.setAllowFileAccess(allow);